firmware_uploader_python
========================

Uploads firmware to multiple embedded devices.

Authors::

    Peter Polidoro <peterpolidoro@gmail.com>

License::

    BSD

Example Usage::

    from firmware_uploader import FirmwareUploader
